## Version 0.0.28

This version includes several enhancements and new features, including the addition of new modules and functions, improvements to documentation, and minor updates to notebooks.

### New Features

- Added `pyperclip` to environment spec and requirements (e57f7f) (Eric Ma)
- Added additional config path for llamabot's OpenAI API key (713579) (Eric Ma)
- Added function for getting function source from a .py file (07e402) (Eric Ma)
- Added `get_valid_input` for user prompts (b001d2) (Eric Ma)
- Initial commit of llamabot's python bot (e5c67d) (Eric Ma)
- Added `read_file` to the `file_finder.py` source file (5b44d5) (Eric Ma)
- Added `PromptRecorder` module documentation (2f208e) (Eric Ma)
- Added explanation of where `autorecord` function is supposed to be used (b7a02c) (Eric Ma)
- Added doc processor documentation (be1bf8) (Eric Ma)
- Added in tutorials ghostwritten by GPT4 (ace0cd) (Eric Ma)

### Bug Fixes

- Minor update to scratch notebooks (dc1f76) (Eric Ma)
- Minor changes on doc processor (4601eb) (Eric Ma)

### Deprecations

- No deprecations in this release.

### Documentation

- Updated module-level docstring for CLI init (ef812f) (Eric Ma)
- Added module-level docstring prompt (7be6ad) (Eric Ma)
- Updated docstring based on Llamabot (6d9829) (Eric Ma)
- Improved `doc_processor` docstring (fb98de) (Eric Ma)
- Moved notebooks to examples under docs (998b2d) (Eric Ma)
- Added note on doc processor documentation that it was written by GPT4 (83abc9) (Eric Ma)
- Added notes about tutorial being written by GPT in an official modal (4bb2a4) (Eric Ma)
